@@ -26,7 +26,6 @@ import re
 import subprocess
 import sys
 
-from d2to1.extern import six
 from distutils.command import install as du_install
 import distutils.errors
 from distutils import log
@@ -34,6 +33,11 @@ import pkg_resources
 from setuptools.command import install
 from setuptools.command import sdist
 
+try:
+    import cStringIO as io
+except ImportError:
+    import io
+
 log.set_verbosity(log.INFO)
 TRUE_VALUES = ('true', '1', 'yes')
 REQUIREMENTS_FILES = ('requirements.txt', 'tools/pip-requires')
@@ -88,16 +92,20 @@ def _missing_requires(requires):
 
 
 def _pip_install(links, requires, root=None):
+    if str(os.getenv('SKIP_PIP_INSTALL', '')).lower() in TRUE_VALUES:
+        return
     root_cmd = ""
     if root:
         root_cmd = "--root=%s" % root
-    _run_shell_command(
-        "%s -m pip.__init__ install %s %s %s" % (
-            sys.executable,
-            root_cmd,
-            " ".join(links),
-            " ".join(_wrap_in_quotes(_missing_requires(requires)))),
-        throw_on_error=True, buffer=False)
+    missing_requires = _missing_requires(requires)
+    if missing_requires:
+        _run_shell_command(
+            "%s -m pip.__init__ install %s %s %s" % (
+                sys.executable,
+                root_cmd,
+                " ".join(links),
+                " ".join(_wrap_in_quotes(missing_requires))),
+            throw_on_error=True, buffer=False)
 
 
 def read_git_mailmap(git_dir, mailmap='.mailmap'):
@@ -111,7 +119,7 @@ def canonicalize_emails(changelog, mapping):
     """Takes in a string and an email alias mapping and replaces all
        instances of the aliases in the string with their real email.
     """
-    for alias, email_address in six.iteritems(mapping):
+    for alias, email_address in mapping.items():
         changelog = changelog.replace(alias, email_address)
     return changelog
 
@@ -260,7 +268,7 @@ def generate_authors(git_dir=None, dest_dir='.', option_dict=dict()):
     if not should_skip:
         old_authors = os.path.join(dest_dir, 'AUTHORS.in')
         new_authors = os.path.join(dest_dir, 'AUTHORS')
-        # If there's already a ChangeLog and it's not writable, just use it
+        # If there's already an AUTHORS file and it's not writable, just use it
         if (os.path.exists(new_authors)
                 and not os.access(new_authors, os.W_OK)):
             return
@@ -285,11 +293,11 @@ def generate_authors(git_dir=None, dest_dir='.', option_dict=dict()):
 
             mailmap = read_git_mailmap(git_dir)
             with open(new_authors, 'wb') as new_authors_fh:
-                new_authors_fh.write(canonicalize_emails(
-                    changelog, mailmap).encode('utf-8'))
                 if os.path.exists(old_authors):
                     with open(old_authors, "rb") as old_authors_fh:
-                        new_authors_fh.write(b'\n' + old_authors_fh.read())
+                        new_authors_fh.write(old_authors_fh.read())
+                new_authors_fh.write(canonicalize_emails(
+                    changelog, mailmap).encode('utf-8'))
 
 
 _rst_template = """%(heading)s
@@ -344,7 +352,7 @@ def _newer_requires_files(egg_info_dir):
         for src in _any_existing(sources):
             if (not os.path.exists(target_path) or
                     os.path.getmtime(target_path)
-                    < os.path.getmtime(os.path.join(egg_info_dir, src))):
+                    < os.path.getmtime(src)):
                 return True
     return False
 
@@ -361,13 +369,15 @@ class _PipInstallTestRequires(object):
 
     def install_test_requirements(self):
 
-        links = _make_links_args(_any_existing(TEST_REQUIREMENTS_FILES))
+        links = _make_links_args(
+            parse_dependency_links(TEST_REQUIREMENTS_FILES))
         if self.distribution.tests_require:
-            _pip_install(links, self.distribution.tests_requires)
+            _pip_install(links, self.distribution.tests_require)
 
     def pre_run(self):
         self.egg_name = pkg_resources.safe_name(self.distribution.get_name())
-        self.egg_info = "%s.egg-info" % self.egg_name
+        self.egg_info = "%s.egg-info" % pkg_resources.to_filename(
+            self.egg_name)
         if (not os.path.exists(self.egg_info) or
                 _newer_requires_files(self.egg_info)):
             ei_cmd = self.get_finalized_command('egg_info')
@@ -481,7 +491,7 @@ try:
 
         def _sphinx_run(self):
             if not self.verbose:
-                status_stream = six.StringIO()
+                status_stream = io.StringIO()
             else:
                 status_stream = sys.stdout
             confoverrides = {}
@@ -620,7 +630,9 @@ def get_version(package_name, pre_version=None):
     to make a source tarball from a fork of our repo with additional tags in it
     that they understand and desire the results of doing that.
     """
-    version = os.environ.get("OSLO_PACKAGE_VERSION", None)
+    version = os.environ.get(
+        "PBR_VERSION",
+        os.environ.get("OSLO_PACKAGE_VERSION", None))
     if version:
         return version
     version = _get_version_from_pkg_info(package_name)
